<?php
/**
 * @package BigButtons
 */

/**
 * Theme Settings
 */
include( get_template_directory() . '/theme-options.php' );

function big_buttons_setup() {

		/*
		 * Define $content_width global variable, to keep 
		 * media content from overflowing the Theme's
		 * main content area.
		 */
		global $content_width;
		if ( ! isset( $content_width ) ) {
			$content_width = 840;
		}

		/*
		 * Add Theme support for Automatic Feed Links
		 * 
		 * Automatically add RSS feed links to document header 
		 * 
		 * @since	WordPress 2.9.0
		 */
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Add Theme support for Post Thumbnails
		 * 
		 * Allow users to specify "featured" images for Posts
		 * 
		 * @since	WordPress 2.9.0
		 */
		add_theme_support( 'post-thumbnails' ); 

		/*
		 * Define Custom Image Size for Post Header (since WordPress 3.0)
		 */
		add_image_size( 'post-header-featured', 863, 9999, false );

		/*
		 * Add Theme support for Custom Backgrounds
		 * 
		 * Allow users to specify a custom background image
		 * or color.
		 * 
		 * @since	WordPress 3.0.0
		 */
		add_custom_background();

		/*
		 * Define Nav Menus (since WordPress 3.0)
		 */
		register_nav_menus( array(
			'nav-header' => 'Header Navigation',
			'nav-footer' => 'Footer Navigation',
		) );
}
add_action( 'after_setup_theme', 'big_buttons_setup' );

function big_buttons_widgets() {

	register_sidebar( array(
		'name'=>'Header Right',
		'id'=>'header-right',
		'description' => 'Right side of the header area',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '',
		'after_title' => ''
	) );

	register_sidebar( array(
		'name'=>'Footer Left',
		'id'=>'footer-left',
		'description' => 'Left side of the footer area',
		'before_widget' => '<div id="%1$s" class="widget %2$s">',
		'after_widget' => '</div>',
		'before_title' => '',
		'after_title' => ''
	) );

}
add_action( 'widgets_init', 'big_buttons_widgets' );

/**
 * Enqueue comment-reply script
 */
function big_buttons_enqueue_comment_reply() {
	// on single blog post pages with comments open and threaded comments
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) { 
		// enqueue the javascript that performs in-link comment reply fanciness
		wp_enqueue_script( 'comment-reply' ); 
	}
}
// Hook into wp_enqueue_scripts
add_action( 'wp_enqueue_scripts', 'big_buttons_enqueue_comment_reply' );


/**
 * Filter the_title 
 * 
 * Filter 'the_title' to output '(Untitled)' if 
 * no Post Title is provided
 */
function big_buttons_untitled_post( $title ) {
	if ( '' == $title ) {
		return '<em>(' . __( 'Untitled', 'oenology' ) . ')</em>';
	} else {
		return $title;
	}
}
add_filter( 'the_title', 'big_buttons_untitled_post', 10, 1 );


/**
 * Filter 'get_comments_number'
 * 
 * Filter 'get_comments_number' to display correct 
 * number of comments (count only comments, not 
 * trackbacks/pingbacks)
 * 
 * @link	http://www.wpbeginner.com/wp-tutorials/display-the-most-accurate-comment-count-in-wordpress/ WPBeginner
 */
function big_buttons_comment_count( $count ) {  
	if ( ! is_admin() ) {
		global $id;
		$comments_by_type = &separate_comments(get_comments('status=approve&post_id=' . $id));
		return count($comments_by_type['comment']);
	} else {
		return $count;
	}
}
add_filter('get_comments_number', 'big_buttons_comment_count', 0);

/**
 * wp_list_comments() Pings Callback
 * 
 * wp_list_comments() Callback function for 
 * Pings (Trackbacks/Pingbacks)
 */
function big_buttons_comment_list_pings( $comment ) {
	$GLOBALS['comment'] = $comment;
?>
	<li <?php comment_class(); ?> id="li-comment-<?php comment_ID(); ?>"><?php echo comment_author_link(); ?></li>
<?php }



/**
 * wp_nav_menu() Callback
 * 
 * wp_nav_menu() Callback function for 
 * displaying a page menu when no custom
  * nav menu is defined for a Theme Location
 */
function big_buttons_wp_nav_menu_fallback() {
?>
<div id="pixopoint_menu1">
	<ul id="suckerfishnav" class="sf-menu sf-js-enabled">
	<?php 
	wp_list_pages( array(
		'title_li' => '',
	) );
	?>
	</ul>
</div>
<?php }

?>