<?php
/**
 * Big Buttons Theme Options
 *
 * This file defines the Options for the Big Buttons Theme.
 * 
 * Theme Options Functions
 * 
 *  - Define Default Theme Options
 *  - Register/Initialize Theme Options
 *  - Define Admin Settings Page
 *  - Register Contextual Help
 * 
 * @package 	BigButtons
 */

/**
 * Globalize the variable that holds the Theme Options
 * 
 * @global	array	$big_buttons_options	holds Theme options
 */
global $big_buttons_options;

/**
 * Big Buttons Theme Default Options
 * 
 * Array that holds all the default options for
 * Big Buttons. The 'type' key is used to generate
 * the proper form field markup and to sanitize
 * the user-input data properly. The 'tab' key
 * determines the Settings Page on which the
 * option appears, and the 'section' tab determines
 * the section of the Settings Page tab in which
 * the option appears.
 */
function big_buttons_get_default_options() {

    $options = array(
        'use_header_logo' => array(
			'name' => 'use_header_logo',
			'title' => 'Use Header Logo',
			'type' => 'checkbox',
			'description' => 'Use a logo image instead of the site name in the header',
			'tab' => 'general',
			'section' => 'header',
			'since' => '1.0',
			'default' => false
		),
        'header_logo' => array(
			'name' => 'header_logo',
			'title' => 'Header Logo',
			'type' => 'file',
			'description' => 'Upload a header logo image; maximum image size:  418px by 54px.',
			'tab' => 'general',
			'section' => 'header',
			'since' => '1.0',
			'default' => false
		),
		'facebook_profile' => array(
			'name' => 'facebook_profile',
			'title' => 'Facebook Profile',
			'type' => 'text',
			'sanitize' => 'nohtml',
			'description' => 'Facebook Username',
			'tab' => 'general',
			'section' => 'header',
			'since' => '1.0',
			'default' => ''
		),
		'twitter_profile' => array(
			'name' => 'twitter_profile',
			'title' => 'Twitter Profile',
			'type' => 'text',
			'sanitize' => 'nohtml',
			'description' => 'Twitter Username',
			'tab' => 'general',
			'section' => 'header',
			'since' => '1.0',
			'default' => ''
		),
		'youtube_profile' => array(
			'name' => 'youtube_profile',
			'title' => 'YouTube Profile',
			'type' => 'text',
			'sanitize' => 'nohtml',
			'description' => 'YouTube Username',
			'tab' => 'general',
			'section' => 'header',
			'since' => '1.0',
			'default' => ''
		),
        'frontpage_main_image' => array(
			'name' => 'frontpage_main_image',
			'title' => 'Image File',
			'type' => 'file',
			'max_width' => 622,
			'max_height' => 444,
			'description' => 'Upload an image to be used as the main image on the Front Page; maximum image size:  622px by 444px.',
			'tab' => 'general',
			'section' => 'frontpagemain',
			'since' => '1.0',
			'default' => get_template_directory_uri() . '/images/front-page-main.png'
		),
        'frontpage_main_link' => array(
			'name' => 'frontpage_main_link',
			'title' => 'Link',
			'type' => 'select',
			'valid_options' => big_buttons_get_pages(),
			'description' => 'Page to link to the Front Page main image',
			'tab' => 'general',
			'section' => 'frontpagemain',
			'since' => '1.0',
			'default' => home_url()
		),
		'frontpage_right_link_color' => array(
			'name' => 'frontpage_right_link_color',
			'title' => 'Link Color',
			'type' => 'text',
			'sanitize' => 'hex',
			'description' => 'Enter a custom color (HEX value)',
			'tab' => 'general',
			'section' => 'frontpageright',
			'since' => '1.0',
			'default' => 'ffffff'
		),
        'frontpage_right1_image' => array(
			'name' => 'frontpage_right1_image',
			'title' => 'Image 1 File',
			'type' => 'file',
			'max_width' => 226,
			'max_height' => 128,
			'description' => 'Upload an image to be used as the first right-side image on the Front Page; maximum image size:  226px by 128px.',
			'tab' => 'general',
			'section' => 'frontpageright',
			'since' => '1.0',
			'default' => get_template_directory_uri() . '/images/front-page-right.png'
		),
        'frontpage_right1_link' => array(
			'name' => 'frontpage_right1_link',
			'title' => 'Image 1 Link',
			'type' => 'select',
			'valid_options' => big_buttons_get_pages(),
			'description' => 'Page to link to the first right-side image on the Front Page',
			'tab' => 'general',
			'section' => 'frontpageright',
			'since' => '1.0',
			'default' => home_url()
		),
		'frontpage_right1_linktext' => array(
			'name' => 'frontpage_right1_linktext',
			'title' => 'Image 1 Link Text',
			'type' => 'text',
			'sanitize' => 'nohtml',
			'description' => 'Link text to display for the first right-side image',
			'tab' => 'general',
			'section' => 'frontpageright',
			'since' => '1.0',
			'default' => 'Click Here'
		),
		'frontpage_right1_teasertext' => array(
			'name' => 'frontpage_right1_teasertext',
			'title' => 'Image 1 Teaser Text',
			'type' => 'text',
			'sanitize' => 'nohtml',
			'description' => 'Teaser text to display for the first right-side image',
			'tab' => 'general',
			'section' => 'frontpageright',
			'since' => '1.0',
			'default' => ''
		),
        'frontpage_right2_image' => array(
			'name' => 'frontpage_right2_image',
			'title' => 'Image 2 File',
			'type' => 'file',
			'max_width' => 226,
			'max_height' => 128,
			'description' => 'Upload an image to be used as the second right-side image on the Front Page; maximum image size:  226px by 128px.',
			'tab' => 'general',
			'section' => 'frontpageright',
			'since' => '1.0',
			'default' => get_template_directory_uri() . '/images/front-page-right.png'
		),
        'frontpage_right2_link' => array(
			'name' => 'frontpage_right2_link',
			'title' => 'Image 2 Link',
			'type' => 'select',
			'valid_options' => big_buttons_get_pages(),
			'description' => 'Page to link to the second right-side image on the Front Page',
			'tab' => 'general',
			'section' => 'frontpageright',
			'since' => '1.0',
			'default' => home_url()
		),
		'frontpage_right2_linktext' => array(
			'name' => 'frontpage_right2_linktext',
			'title' => 'Image 2 Link Text',
			'type' => 'text',
			'sanitize' => 'nohtml',
			'description' => 'Link text to display for the second right-side image',
			'tab' => 'general',
			'section' => 'frontpageright',
			'since' => '1.0',
			'default' => 'Click Here'
		),
		'frontpage_right2_teasertext' => array(
			'name' => 'frontpage_right2_teasertext',
			'title' => 'Image 2 Teaser Text',
			'type' => 'text',
			'sanitize' => 'nohtml',
			'description' => 'Teaser text to display for the second right-side image',
			'tab' => 'general',
			'section' => 'frontpageright',
			'since' => '1.0',
			'default' => ''
		),
        'frontpage_right3_image' => array(
			'name' => 'frontpage_right3_image',
			'title' => 'Image 3 File',
			'type' => 'file',
			'max_width' => 226,
			'max_height' => 128,
			'description' => 'Upload an image to be used as the third right-side image on the Front Page; maximum image size:  226px by 128px.',
			'tab' => 'general',
			'section' => 'frontpageright',
			'since' => '1.0',
			'default' => get_template_directory_uri() . '/images/front-page-right.png'
		),
        'frontpage_right3_link' => array(
			'name' => 'frontpage_right3_link',
			'title' => 'Image 3 Link',
			'type' => 'select',
			'valid_options' => big_buttons_get_pages(),
			'description' => 'Page to link to the third right-side image on the Front Page',
			'tab' => 'general',
			'section' => 'frontpageright',
			'since' => '1.0',
			'default' => home_url()
		),
		'frontpage_right3_linktext' => array(
			'name' => 'frontpage_right3_linktext',
			'title' => 'Image 3 Link Text',
			'type' => 'text',
			'sanitize' => 'nohtml',
			'description' => 'Link text to display for the third right-side image',
			'tab' => 'general',
			'section' => 'frontpageright',
			'since' => '1.0',
			'default' => 'Click Here'
		),
		'frontpage_right3_teasertext' => array(
			'name' => 'frontpage_right3_teasertext',
			'title' => 'Image 3 Teaser Text',
			'type' => 'text',
			'sanitize' => 'nohtml',
			'description' => 'Teaser text to display for the third right-side image',
			'tab' => 'general',
			'section' => 'frontpageright',
			'since' => '1.0',
			'default' => ''
		),
        'frontpage_bottom1_image' => array(
			'name' => 'frontpage_bottom1_image',
			'title' => 'Image 1 File',
			'type' => 'file',
			'max_width' => 284,
			'max_height' => 80,
			'description' => 'Upload an image to be used as the first bottom image on the Front Page; maximum image size:  284px by 80px.',
			'tab' => 'general',
			'section' => 'frontpagebottom',
			'since' => '1.0',
			'default' => get_template_directory_uri() . '/images/front-page-bottom.png'
		),
        'frontpage_bottom1_link' => array(
			'name' => 'frontpage_bottom1_link',
			'title' => 'Image 1 Link',
			'type' => 'select',
			'valid_options' => big_buttons_get_pages(),
			'description' => 'Page to link to the first bottom image on the Front Page',
			'tab' => 'general',
			'section' => 'frontpagebottom',
			'since' => '1.0',
			'default' => home_url()
		),
        'frontpage_bottom2_image' => array(
			'name' => 'frontpage_bottom2_image',
			'title' => 'Image 2 File',
			'type' => 'file',
			'max_width' => 284,
			'max_height' => 80,
			'description' => 'Upload an image to be used as the second bottom image on the Front Page; maximum image size:  284px by 80px.',
			'tab' => 'general',
			'section' => 'frontpagebottom',
			'since' => '1.0',
			'default' => get_template_directory_uri() . '/images/front-page-bottom.png'
		),
        'frontpage_bottom2_link' => array(
			'name' => 'frontpage_bottom2_link',
			'title' => 'Image 2 Link',
			'type' => 'select',
			'valid_options' => big_buttons_get_pages(),
			'description' => 'Page to link to the second bottom image on the Front Page',
			'tab' => 'general',
			'section' => 'frontpagebottom',
			'since' => '1.0',
			'default' => home_url()
		),
        'frontpage_bottom3_image' => array(
			'name' => 'frontpage_bottom3_image',
			'title' => 'Image 3 File',
			'type' => 'file',
			'max_width' => 284,
			'max_height' => 80,
			'description' => 'Upload an image to be used as the third bottom image on the Front Page; maximum image size:  284px by 80px.',
			'tab' => 'general',
			'section' => 'frontpagebottom',
			'since' => '1.0',
			'default' => get_template_directory_uri() . '/images/front-page-bottom.png'
		),
        'frontpage_bottom3_link' => array(
			'name' => 'frontpage_bottom3_link',
			'title' => 'Image 3 Link',
			'type' => 'select',
			'valid_options' => big_buttons_get_pages(),
			'description' => 'Page to link to the third bottom image on the Front Page',
			'tab' => 'general',
			'section' => 'frontpagebottom',
			'since' => '1.0',
			'default' => home_url()
		)
    );
    return $options;
}

/**
 * Get a list of all Pages
 * 
 * Array that holds all of the static Pages.
 */
function big_buttons_get_pages() {
	
	$pages = get_pages( array(
		'post_type' => 'page',
		'post_status' => 'publish'
	) );
	$pagelist = array();
	foreach ( $pages as $thepage ) {
		$pageid = $thepage->ID;
		$pagetitle = $thepage->post_title;
		$pagelist[$pageid] = array(
			'name' => $pageid,
			'title' => $pagetitle
		);
	}
	return $pagelist;
}


/**
 * Separate settings by tab
 */
function big_buttons_get_settings_by_tab() {
	$tabs = big_buttons_get_settings_page_tabs();
	$tabnames = array();
	foreach ( $tabs as $tab ) {
		$tabname = $tab['name'];
		$tabnames[] = $tabname;
	}
	$settingsbytab = $tabnames;
	$default_options = big_buttons_get_default_options();
	foreach ( $default_options as $default_option ) {
		if ( 'internal' != $default_option['type'] ) {
			$optiontab = $default_option['tab'];
			$optionname = $default_option['name'];
			$settingsbytab[$optiontab][] = $optionname;
		}
	}
	return $settingsbytab;
}

/**
 * Big Buttons Theme Admin Settings Page Tabs
 * 
 * Array that holds all of the tabs for the
 * Big Buttons Theme Settings Page. Each tab
 * key holds an array that defines the 
 * sections for each tab, including the
 * description text.
 */
function big_buttons_get_settings_page_tabs() {
	
	$tabs = array( 
        'general' => array(
			'name' => 'general',
			'title' => 'General',
			'sections' => array(
				'header' => array(
					'name' => 'header',
					'title' =>'Header Options',
					'description' => 'Manage Header options for the Big Buttons Theme.'
				),
				'frontpagemain' => array(
					'name' => 'frontpagemain',
					'title' => 'Front Page Main Image',
					'description' => 'Manage Front Page main image options for the Big Buttons Theme.'
				),
				'frontpageright' => array(
					'name' => 'frontpageright',
					'title' => 'Front Page Right-Side Images',
					'description' => 'Manage Front Page right-side images options for the Big Buttons Theme.'
				),
				'frontpagebottom' => array(
					'name' => 'frontpagebottom',
					'title' => 'Front Page Bottom Images',
					'description' => 'Manage Front Page bottom images options for the Big Buttons Theme.'
				)
			)
		)
    );
	return $tabs;
}


/**
 * Setup initial Theme options
 */
function big_buttons_options_init() {

	// set options equal to defaults
	global $big_buttons_options;
	$big_buttons_options = get_option( 'theme_big_buttons_options' );
	$default_options = big_buttons_get_default_options();
	
	if ( false === $big_buttons_options ) {
		$big_buttons_options = array();
		foreach ( $default_options as $default_option ) {
			$optionname = $default_option['name'];
			$optiondefault = $default_option['default'];
			$big_buttons_options[$optionname] = $optiondefault;
		}
	}
	$defaults = array();
	foreach ( $default_options as $default_option ) {
		$optionname = $default_option['name'];
		$optiondefault = $default_option['default'];
		$defaults[$optionname] = $optiondefault;
	}
	$big_buttons_options = array_merge( $defaults, $big_buttons_options );
	update_option( 'theme_big_buttons_options', $big_buttons_options );
}
// Initialize Theme options
add_action('after_setup_theme', 'big_buttons_options_init', 9 );

/**
 * Enqueue Custom Styles
 */
function big_buttons_enqueue_style() { 
	
	$big_buttons_options = get_option( 'theme_big_buttons_options' );
	
?>

<style type="text/css">

#rightpics,
#rightpics a:link {
	color:#<?php esc_attr_e( $big_buttons_options['frontpage_right_link_color'] ) ?>
}
#right1 {
	background-image: url("<?php echo esc_url( $big_buttons_options['frontpage_right1_image'] ); ?>");
}
#right2 {
	background-image: url("<?php echo esc_url( $big_buttons_options['frontpage_right2_image'] ); ?>");
}
#right3 {
	background-image: url("<?php echo esc_url( $big_buttons_options['frontpage_right3_image'] ); ?>");
}

</style>
	
<?php }
// Enqueue Varietal Stylesheet at wp_print_styles()
add_action('wp_print_styles', 'big_buttons_enqueue_style', 11 );

/**
 * Filter Capability for Theme Settings Page
 * 
 * This filter implements a WordPress 3.2 fix for
 * a minor bug, in which add_theme_page() is passed
 * the "edit_theme_options" capability, but the
 * settings page form is passed through options.php,
 * which expects the "manage_options" capability.
 * 
 * The "edit_theme_options" capability is part of the
 * EDITOR user role, while "manage_options" is only
 * available to the ADMINISTRATOR role. So, users in
 * the EDITOR user role can access the Theme settings
 * page, but are unable actually to update/save the
 * Theme settings.
 * 
 * The function is hooked into a hook, introduced in
 * WordPress 3.2: "option_page_capability_{option_page}",
 * where {option_page} is the name of the options page,
 * as defined in the fourth argument of the call to
 * add_theme_page()
 * 
 * The function returns a string consisting of the
 * appropriate capability for saving Theme settings.
 */
function big_buttons_get_settings_page_cap() {
	return 'edit_theme_options';
}
// Hook into option_page_capability_{option_page}
add_action( 'option_page_capability_big-buttons-settings', 'big_buttons_get_settings_page_cap' );

/**
 * Setup the Theme Admin Settings Page
 * 
 * Add "Big Buttons Options" link to the "Appearance" menu
 */
function big_buttons_add_theme_page() {
	add_theme_page(
		// $page_title
		// Name displayed in HTML title tag
		'Big Buttons Options', 
		// $menu_title
		// Name displayed in the Admin Menu
		'Big Buttons Options', 
		// $capability
		// User capability required to access page
		big_buttons_get_settings_page_cap(), 
		// $menu_slug
		// String to append to URL after "themes.php"
		'big-buttons-settings', 
		// $callback
		// Function to define settings page markup
		'big_buttons_admin_options_page'
	);
}
// Load the Admin Options page
add_action('admin_menu', 'big_buttons_add_theme_page');

/**
 * Get current settings page tab
 */
function big_buttons_get_current_tab( $current = 'general' ) {

    if ( isset ( $_GET['tab'] ) ) :
        $current = $_GET['tab'];
    else:
        $current = 'general';
    endif;
	
	return $current;
}

/**
 * Define Big Buttons Theme Settings Page Tab Markup
 * 
 * @link`http://www.onedesigns.com/tutorials/separate-multiple-theme-options-pages-using-tabs	Daniel Tara
 */
function big_buttons_admin_options_page_tabs( $current = 'general' ) {

    $current = big_buttons_get_current_tab();
    
    $tabs = big_buttons_get_settings_page_tabs();
    
    $links = array();
    
    foreach( $tabs as $tab ) :
		$tabname = $tab['name'];
		$tabtitle = $tab['title'];
        if ( $tabname == $current ) :
            $links[] = "<a class='nav-tab nav-tab-active' href='?page=big-buttons-settings&tab=$tabname'>$tabtitle</a>";
        else :
            $links[] = "<a class='nav-tab' href='?page=big-buttons-settings&tab=$tabname'>$tabtitle</a>";
        endif;
    endforeach;
    
    echo '<div id="icon-themes" class="icon32"><br /></div>';
    echo '<h2 class="nav-tab-wrapper">';
    foreach ( $links as $link )
        echo $link;
    echo '</h2>';
    
}

/**
 * Big Buttons Theme Settings Page Markup
 */
function big_buttons_admin_options_page() { 
	$currenttab = big_buttons_get_current_tab();
	$settings_section = 'big_buttons_' . $currenttab . '_tab';
	?>

	<div class="wrap">
		<?php big_buttons_admin_options_page_tabs(); ?>
		<?php if ( isset( $_GET['settings-updated'] ) ) {
    			echo "<div class='updated'><p>Theme settings updated successfully.</p></div>";
		} ?>
		<form action="options.php" method="post" enctype="multipart/form-data">
			<input type="hidden" name="MAX_FILE_SIZE" value="3000000" />
		<?php 
			settings_fields('theme_big_buttons_options');
			do_settings_sections( $settings_section );
			
			$tab = ( isset( $_GET['tab'] ) ? $_GET['tab'] : 'general' );
		?>
			<input name="theme_big_buttons_options[submit-<?php echo $tab; ?>]" type="submit" class="button-primary" value="Save Settings" />
			<input name="theme_big_buttons_options[reset-<?php echo $tab; ?>]" type="submit" class="button-secondary" value="Reset Defaults" />
		</form>
	</div>
<?php 
}

/**
 * Big Buttons Theme Settings API Implementation
 *
 * Implement the WordPress Settings API for the 
 * Big Buttons Theme Settings.
 * 
 * @link	http://codex.wordpress.org/Settings_API	Codex Reference: Settings API
 * @link	http://ottopress.com/2009/wordpress-settings-api-tutorial/	Otto
 * @link	http://planetozh.com/blog/2009/05/handling-plugins-options-in-wordpress-28-with-register_setting/	Ozh
 */
function big_buttons_register_options(){

	/**
	* Register Theme Settings
	* 
	* Register theme_big_buttons_options array to hold
	* all Theme options.
	* 
	* @link	http://codex.wordpress.org/Function_Reference/register_setting	Codex Reference: register_setting()
	* 
	* @param	string		$option_group		Unique Settings API identifier; passed to settings_fields() call
	* @param	string		$option_name		Name of the wp_options database table entry
	* @param	callback	$sanitize_callback	Name of the callback function in which user input data are sanitized
	*/
	register_setting( 
		// $option_group
		'theme_big_buttons_options', 
		// $option_name
		'theme_big_buttons_options', 
		// $sanitize_callback
		'big_buttons_options_validate' 
	);

	/**
	* Theme register_settin() sanitize callback
	* 
	* Validate and whitelist user-input data before updating Theme 
	* Options in the database. Only whitelisted options are passed
	* back to the database, and user-input data for all whitelisted
	* options are sanitized.
	* 
	* @link	http://codex.wordpress.org/Data_Validation	Codex Reference: Data Validation
	* 
	* @param	array	$input	Raw user-input data submitted via the Theme Settings page
	* @return	array	$input	Sanitized user-input data passed to the database
	*/
	function big_buttons_options_validate( $input ) {
		// This is the "whitelist": current settings
		$valid_input = get_option( 'theme_big_buttons_options' );
		// Get the array of Theme settings, by Settings Page tab
		$settingsbytab = big_buttons_get_settings_by_tab();
		// Get the array of default options
		$default_options = big_buttons_get_default_options();
		
		// Determine what type of submit was input
		$submittype = ( ! empty( $input['submit-general'] ) ? 'submit' : 'reset' );
		// Determine what tab was input
		$submittab = 'general';
		// Get settings by tab
		$tabsettings = $settingsbytab[$submittab];
		// Loop through each tab setting
		foreach ( $tabsettings as $setting ) {
			// If submit, validate/sanitize $input
			if ( 'submit' == $submittype ) {
				$optiondetails = false;
				// Loop through the array of default options
				foreach ( $default_options as $default_option ) {
					// Find the current setting in the array of default options
					if ( $default_option['name'] == $setting ) {
						// Pull out the array for the current setting
						$optiondetails = $default_option;
					}
				}
				// Validate checkbox fields
				if ( 'checkbox' == $optiondetails['type'] ) {
					// If input value is set and is true, return true; otherwise return false
					$valid_input[$setting] = ( ( isset( $input[$setting] ) && true == $input[$setting] ) ? true : false );
				}
				// Validate radio button fields
				else if ( 'radio' == $optiondetails['type'] ) {
					// Get the list of valid options
					$valid_options = $optiondetails['valid_options'];
					// Only update setting if input value is in the list of valid options
					$valid_input[$setting] = ( array_key_exists( $input[$setting], $valid_options ) ? $input[$setting] : $valid_input[$setting] );
				}
				// Validate select fields
				else if ( 'select' == $optiondetails['type'] ) {
					// Get the list of valid options
					$valid_options = $optiondetails['valid_options'];
					// Only update setting if input value is in the list of valid options
					$valid_input[$setting] = ( array_key_exists( $input[$setting], $valid_options ) ? $input[$setting] : $valid_input[$setting] );
				}
				// Validate text input and textarea fields
				else if ( ( 'text' == $optiondetails['type'] || 'textarea' == $optiondetails['type'] ) ) {
					// Validate no-HTML content
					if ( 'nohtml' == $optiondetails['sanitize'] ) {
						// Pass input data through the wp_filter_nohtml_kses filter
						$valid_input[$setting] = wp_filter_nohtml_kses( $input[$setting] );
					}
					// Validate HTML content
					else if ( 'html' == $optiondetails['sanitize'] ) {
						// Pass input data through the wp_filter_kses filter
						$valid_input[$setting] = wp_filter_post_kses( $input[$setting] );
					}
					// Validate HEX content
					else if ( 'hex' == $optiondetails['sanitize'] ) {
						// Clean up the HEX value
						$hex = trim( $input[$setting] );
						if ( 0 === strpos( $hex, '#' ) ) {
							$hex = substr( $hex, 1 );
						} elseif ( 0 === strpos( $hex, '%23' ) ) {
							$hex = substr( $hex, 3 );
						}	
						$valid_input[$setting] = ( 0 !== preg_match( '/^[0-9a-fA-F]{6}$/', $hex ) ? $hex : $valid_input[$setting] );
					}
				// Validate file uploads
				} else if ( 'file' == $optiondetails['type'] ) {
					if ( isset( $_FILES[$setting . '_file'] ) ) {
						$data = $_FILES[$setting . '_file'];
						if ( '' != $data['name'] ) {
							$upload = wp_handle_upload( $_FILES[$setting . '_file'], array( 'test_form' => false ) );
						} else {
							$upload['url'] = $input[$setting];
						}
						$valid_input[$setting] = $upload['url'];
					}
				}
			} 
			// If reset, reset defaults
			elseif ( 'reset' == $submittype ) {
				// Get the array for $setting
				$option = $default_options[$setting];
				// Set $setting to the default value
				$valid_input[$setting] = $option['default'];
			}
		}
		return $valid_input;		

	}

	/**
	* Globalize the variable that holds 
	* the Settings Page tab definitions
	* 
	* @global	array	Settings Page Tab definitions
	*/
	global $big_buttons_tabs;
	$big_buttons_tabs = big_buttons_get_settings_page_tabs();
	/**
	* Call add_settings_section() for each Settings 
	* 
	* Loop through each Theme Settings page tab, and add 
	* a new section to the Theme Settings page for each 
	* section specified for each tab.
	* 
	* @link	http://codex.wordpress.org/Function_Reference/add_settings_section	Codex Reference: add_settings_section()
	* 
	* @param	string		$sectionid	Unique Settings API identifier; passed to add_settings_field() call
	* @param	string		$title		Title of the Settings page section
	* @param	callback	$callback	Name of the callback function in which section text is output
	* @param	string		$pageid		Name of the Settings page to which to add the section; passed to do_settings_sections()
	*/
	foreach ( $big_buttons_tabs as $tab ) {
		$tabname = $tab['name'];
		$tabsections = $tab['sections'];
		foreach ( $tabsections as $section ) {
			$sectionname = $section['name'];
			$sectiontitle = $section['title'];
			// Add settings section
			add_settings_section(
				// $sectionid
				'big_buttons_' . $sectionname . '_section',
				// $title
				$sectiontitle,
				// $callback
				'big_buttons_sections_callback',
				// $pageid
				'big_buttons_' . $tabname . '_tab'
			);
		}
	}

	/**
	* Callback for add_settings_section()
	* 
	* Generic callback to output the section text
	* for each Plugin settings section. 
	* 
	* @param	array	$section_passed	Array passed from add_settings_section()
	*/
	function big_buttons_sections_callback( $section_passed ) {
		global $big_buttons_tabs;
		$big_buttons_hooks_tabs = big_buttons_get_settings_page_tabs();
		foreach ( $big_buttons_tabs as $tab ) {
			$tabname = $tab['name'];
			$tabsections = $tab['sections'];
			foreach ( $tabsections as $section ) {
				$sectionname = $section['name'];
				$sectiondescription = $section['description'];
				$section_callback_id = 'big_buttons_' . $sectionname . '_section';
				if ( $section_callback_id == $section_passed['id'] ) {
					?>
					<p><?php echo $sectiondescription; ?></p>
					<?php
				}
			}
		}
	}

	/**
	* Globalize the variable that holds 
	* the Theme default settings definitions
	* 
	* @global	array	Theme settings definitions
	*/
	global $default_options;
	$default_options = big_buttons_get_default_options();
	/**
	* Call add_settings_field() for each Setting Field
	* 
	* Loop through each Theme option, and add a new 
	* setting field to the Theme Settings page for each 
	* setting.
	* 
	* @link	http://codex.wordpress.org/Function_Reference/add_settings_field	Codex Reference: add_settings_field()
	* 
	* @param	string		$settingid	Unique Settings API identifier; passed to the callback function
	* @param	string		$title		Title of the setting field
	* @param	callback	$callback	Name of the callback function in which setting field markup is output
	* @param	string		$pageid		Name of the Settings page to which to add the setting field; passed from add_settings_section()
	* @param	string		$sectionid	ID of the Settings page section to which to add the setting field; passed from add_settings_section()
	* @param	array		$args		Array of arguments to pass to the callback function
	*/
	foreach ( $default_options as $option ) {
		$optionname = $option['name'];
		$optiontitle = $option['title'];
		$optiontab = $option['tab'];
		$optionsection = $option['section'];
		$optiontype = $option['type'];
		if ( 'internal' != $optiontype ) {
			add_settings_field(
				// $settingid
				'big_buttons_setting_' . $optionname,
				// $title
				$optiontitle,
				// $callback
				'big_buttons_setting_callback',
				// $pageid
				'big_buttons_' . $optiontab . '_tab',
				// $sectionid
				'big_buttons_' . $optionsection . '_section',
				// $args
				$option
			);
		}
	}

	/**
	* Callback for get_settings_field()
	*/
	function big_buttons_setting_callback( $option ) {
		$big_buttons_options = get_option( 'theme_big_buttons_options' );
		$default_options = big_buttons_get_default_options();
		$optionname = $option['name'];
		$optiontitle = $option['title'];
		$optiondescription = $option['description'];
		$fieldtype = $option['type'];
		$fieldname = 'theme_big_buttons_options[' . $optionname . ']';
		// Output checkbox form field markup
		if ( 'checkbox' == $fieldtype ) {
			?>
			<input type="checkbox" name="<?php echo $fieldname; ?>" <?php checked( $big_buttons_options[$optionname] ); ?> />
			<?php
		}
		// Output radio button form field markup
		else if ( 'radio' == $fieldtype ) {
			$valid_options = array();
			$valid_options = $option['valid_options'];
			foreach ( $valid_options as $valid_option ) {
				?>
				<input type="radio" name="<?php echo $fieldname; ?>" <?php checked( $valid_option['name'] == $big_buttons_options[$optionname] ); ?> value="<?php echo $valid_option['name']; ?>" />
				<?php
			}
		}
		// Output select form field markup
		else if ( 'select' == $fieldtype ) {
			$valid_options = array();
			$valid_options = $option['valid_options'];
			?>
			<select name="<?php echo $fieldname; ?>">
			<?php 
			foreach ( $valid_options as $valid_option ) {
				?>
				<option <?php selected( $valid_option['name'] == $big_buttons_options[$optionname] ); ?> value="<?php echo $valid_option['name']; ?>"><?php echo $valid_option['title']; ?></option>
				<?php
			}
			?>
			</select>
			<?php
		} 
		// Output text input form field markup
		else if ( 'text' == $fieldtype ) {
			if ( 'nohtml' == $option['sanitize'] ) {
				?>
				<input type="text" name="<?php echo $fieldname; ?>" value="<?php echo wp_filter_nohtml_kses( $big_buttons_options[$optionname] ); ?>" />
				<?php
			} else if ( 'html' == $option['sanitize'] ) {
				?>
				<input type="text" name="<?php echo $fieldname; ?>" value="<?php echo wp_filter_post_kses( $big_buttons_options[$optionname] ); ?>" />
				<?php
			}else if ( 'hex' == $option['sanitize'] ) {
				?>
				<input type="text" name="<?php echo $fieldname; ?>" value="<?php echo wp_filter_nohtml_kses( $big_buttons_options[$optionname] ); ?>" maxlength="6" style="width:6em;" />
				<label for="<?php echo $fieldname; ?>"><span style="min-width:50px;padding:3px;border:1px solid #000;background-color:<?php echo wp_filter_nohtml_kses( $big_buttons_options[$optionname] ); ?>;"><?php echo wp_filter_nohtml_kses( $big_buttons_options[$optionname] ); ?></span></label>
				<?php
			}
		} 
		// Output file input form field markup
		else if ( 'file' == $fieldtype ) {
			?>			
			<input name="<?php echo $optionname; ?>_file" type="file" />
			<?php
			if ( $big_buttons_options[$optionname] ) { ?>
				<div style="overflow:hidden;">
					<img src="<?php echo esc_url( $big_buttons_options[$optionname] ); ?>" style="max-height:150px;width:auto;" alt="" />
				</div>
			<?php }
			?>
			<input type="hidden" name="<?php echo $fieldname; ?>" value="<?php echo esc_attr( $big_buttons_options[$optionname] ); ?>" />
			<?php
		} 
		// Output the setting description
		?>
		<span class="description"><?php echo $optiondescription; ?></span>
		<?php
	}
	
}
// Settings API options initilization and validation
add_action('admin_init', 'big_buttons_register_options');
?>